netris version 0.4
[netris.git] / util.c
diff --git a/util.c b/util.c
index b52d7613f154c610840adc22734fb0987c7b8146..98248ed64e3ab11d625e6fa514325e2ae9c63146 100644 (file)
--- a/util.c
+++ b/util.c
@@ -1,6 +1,6 @@
 /*
* Netris -- A free networked version of Tetris
* Copyright (C) 1994,1995  Mark Weaver <Mark_Weaver@brown.edu>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: util.c,v 1.26 1995/07/11 08:53:32 mhw Exp $
+ * $Id: util.c,v 1.27 1996/02/09 08:22:23 mhw Exp $
  */
 
 #include "netris.h"
@@ -66,74 +66,77 @@ ExtFunc void AtExit(void (*handler)(void))
 ExtFunc void Usage(void)
 {
        fprintf(stderr,
-               "Netris version %s (C) 1994,1995  Mark Weaver <Mark_Weaver@brown.edu>\n"
-               "Usage: netris <options>\n"
-               "  -h           Print usage information\n"
-               "  -w           Wait for connection\n"
-               "  -c <host>    Initiate connection\n"
-               "  -p <port>    Set port number (default is %d)\n"
-               "  -k <keys>    Remap keys.  The argument is a string containing\n"
-               "                 the keys in order: left, rotate, right, drop,\n"
-               "                 down-faster, toggle-spying, pause\n"
-               "  -i <sec>     Set the step-down interval, in seconds\n"
-               "  -r <robot>   Execute <robot> (a command) as a robot controlling\n"
-               "                 the game instead of the keyboard\n"
-               "  -F           Use fair robot interface\n"
-               "  -s <seed>    Start with given random seed\n"
-               "  -D           Drops go into drop mode\n"
-               "                 This means that sliding off a cliff after a drop causes\n"
-               "                 another drop automatically\n"
-               "  -S           Disable standout mode (inverse/bold) for slow terminals\n"
-               "  -H           Show distribution and warranty information\n"
-               "  -R           Show rules\n",
-               version_string, DEFAULT_PORT);
+         "Netris version %s (C) 1994,1995,1996  Mark H. Weaver <mhw@netris.org>\n"
+         "Usage: netris <options>\n"
+         "  -h         Print usage information\n"
+         "  -w         Wait for connection\n"
+         "  -c <host>  Initiate connection\n"
+         "  -p <port>  Set port number (default is %d)\n"
+         "  -k <keys>  Remap keys.  The argument is a prefix of the string\n"
+         "               containing the keys in order: left, rotate, right, drop,\n"
+         "               down-faster, toggle-spying, pause, faster, redraw.\n"
+         "               \"^\" prefixes controls.  (default is \"%s\")\n"
+         "  -i <sec>   Set the step-down interval, in seconds\n"
+         "  -r <robot> Execute <robot> (a command) as a robot controlling\n"
+         "               the game instead of the keyboard\n"
+         "  -F         Use fair robot interface\n"
+         "  -s <seed>  Start with given random seed\n"
+         "  -D         Drops go into drop mode\n"
+         "               This means that sliding off a cliff after a drop causes\n"
+         "               another drop automatically\n"
+         "  -S         Disable standout mode (inverse/bold) for slow terminals\n"
+         "  -H         Show distribution and warranty information\n"
+         "  -R         Show rules\n",
+         version_string, DEFAULT_PORT, DEFAULT_KEYS);
 }
 
 ExtFunc void DistInfo(void)
 {
        fprintf(stderr,
-               "Netris version %s (C) 1994,1995  Mark Weaver <Mark_Weaver@brown.edu>\n"
-               "\n"
-               "This program is free software; you can redistribute it and/or modify\n"
-               "it under the terms of the GNU General Public License as published by\n"
-               "the Free Software Foundation; either version 2 of the License, or\n"
-               "(at your option) any later version.\n"
-               "\n"
-               "This program is distributed in the hope that it will be useful,\n"
-               "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-               "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-               "GNU General Public License for more details.\n"
-               "\n"
-               "You should have received a copy of the GNU General Public License\n"
-               "along with this program; if not, write to the Free Software\n"
-               "Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n",
-               version_string);
+         "Netris version %s (C) 1994,1995,1996  Mark H. Weaver <mhw@netris.org>\n"
+         "\n"
+         "This program is free software; you can redistribute it and/or modify\n"
+         "it under the terms of the GNU General Public License as published by\n"
+         "the Free Software Foundation; either version 2 of the License, or\n"
+         "(at your option) any later version.\n"
+         "\n"
+         "This program is distributed in the hope that it will be useful,\n"
+         "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+         "GNU General Public License for more details.\n"
+         "\n"
+         "You should have received a copy of the GNU General Public License\n"
+         "along with this program; if not, write to the Free Software\n"
+         "Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n",
+         version_string);
 }
 
 ExtFunc void Rules(void)
 {
        fprintf(stderr,
-               "Netris version %s rules\n"
-               "\n"
-               "Two player mode\n"
-               "---------------\n"
-               "It's just like normal Tetris except that when you clear more than\n"
-               "one row with a single piece, the other player's board is moved up\n"
-               "and junk rows are added to the bottom.  If you clear 2, 3 or 4\n"
-               "rows, 1, 2 or 4 junk rows are added to your opponent's board,\n"
-               "respectively.  The junk rows have exactly one empty column.\n"
-               "For each group of junk rows given, the empty columns will line\n"
-               "up.  This is intentional.\n"
-               "\n"
-               "The longest surviving player wins the game.\n"
-               "\n"
-               "One player mode\n"
-               "---------------\n"
-               "This mode is currently very boring, because there's no scoring\n"
-               "and it never gets any faster.  This will be rectified at some point.\n"
-               "I'm not very motivated to do it right now because I'm sick of one\n"
-               "player Tetris.\n",
-               version_string);
+         "Netris version %s rules\n"
+         "\n"
+         "Two player mode\n"
+         "---------------\n"
+         "It's just like normal T*tris except that when you clear more than\n"
+         "one row with a single piece, the other player's board is moved up\n"
+         "and junk rows are added to the bottom.  If you clear 2, 3 or 4\n"
+         "rows, 1, 2 or 4 junk rows are added to your opponent's board,\n"
+         "respectively.  The junk rows have exactly one empty column.\n"
+         "For each group of junk rows given, the empty columns will line\n"
+         "up.  This is intentional.\n"
+         "\n"
+         "The longest surviving player wins the game.\n"
+         "\n"
+         "One player mode\n"
+         "---------------\n"
+         "This mode is currently very boring, because there's no scoring\n"
+         "and it never gets any faster.  This will be rectified at some point.\n"
+         "I'm not very motivated to do it right now because I'm sick of one\n"
+         "player T*tris.  For now, use the \"f\" key (by default) to make the\n"
+         "game go faster.  Speedups cannot be reversed for the remainder of\n"
+         "the game.\n",
+         version_string);
 }
 
 /*
@@ -376,3 +379,7 @@ ExtFunc MyEventType WaitMyEvent(MyEvent *event, int mask)
        }
 }
 
+/*
+ * vi: ts=4 ai
+ * vim: noai si
+ */
@@ -1,6 +1,6 @@
 /*
- * Netris -- A free networked version of Tetris
- * Copyright (C) 1994,1995  Mark Weaver <Mark_Weaver@brown.edu>
+ * Netris -- A free networked version of T*tris
+ * Copyright (C) 1994,1995,1996  Mark H. Weaver <mhw@netris.org>
  * 
  * This program is free software; you can redistribute it and/or